@@ -8,9 +8,10 @@
 #' @template step-return
 #' @family individual transformation steps
 #' @export
-#' @details The inverse logit transformation takes values on the
-#'  real line and translates them to be between zero and one using
-#'  the function `f(x) = 1/(1+exp(-x))`.
+#' @details
+#'
+#' The inverse logit transformation takes values on the real line and translates
+#' them to be between zero and one using the function `f(x) = 1/(1+exp(-x))`.
 #'
 #' # Tidying
 #'
@@ -100,6 +101,10 @@ bake.step_invlogit <- function(object, new_data, ...) {
   col_names <- names(object$columns)
   check_new_data(col_names, object, new_data)
 
+  if (nrow(new_data) == 0) {
+    return(new_data)
+  }
+
   for (col_name in col_names) {
     new_data[[col_name]] <- binomial()$linkinv(new_data[[col_name]])
   }
