@@ -1,34 +1,32 @@
 #' Check range consistency
 #'
-#' `check_range` creates a *specification* of a recipe
-#'  check that will check if the range of a numeric
-#'  variable changed in the new data.
+#' `check_range()` creates a *specification* of a recipe check that will check
+#' if the range of a numeric variable changed in the new data.
 #'
 #' @inheritParams check_missing
-#' @param slack_prop The allowed slack as a proportion of the range
-#'   of the variable in the train set.
-#' @param warn If `TRUE` the check will throw a warning instead
-#'   of an error when failing.
-#' @param lower A named numeric vector of minimum values in the train set.
-#'   This is `NULL` until computed by [prep()].
-#' @param upper A named numeric vector of maximum values in the train set.
-#'   This is `NULL` until computed by [prep()].
+#' @param slack_prop The allowed slack as a proportion of the range of the
+#'   variable in the train set.
+#' @param warn If `TRUE` the check will throw a warning instead of an error when
+#'   failing.
+#' @param lower A named numeric vector of minimum values in the train set. This
+#'   is `NULL` until computed by [prep()].
+#' @param upper A named numeric vector of maximum values in the train set. This
+#'   is `NULL` until computed by [prep()].
 #' @template check-return
 #' @family checks
 #' @export
 #' @details
-#'   The amount of slack that is allowed is determined by the
-#'   `slack_prop`. This is a numeric of length one or two. If
-#'   of length one, the same proportion will be used at both ends
-#'   of the train set range. If of length two, its first value
-#'   is used to compute the allowed slack at the lower end,
-#'   the second to compute the allowed slack at the upper end.
 #'
-#'  # Tidying
+#' The amount of slack that is allowed is determined by the `slack_prop`. This
+#' is a numeric of length one or two. If of length one, the same proportion will
+#' be used at both ends of the train set range. If of length two, its first
+#' value is used to compute the allowed slack at the lower end, the second to
+#' compute the allowed slack at the upper end.
 #'
-#'  When you [`tidy()`][tidy.recipe()] this check, a tibble with columns
-#'  `terms` (the selectors or variables selected) and `value` (the means)
-#'  is returned.
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this check, a tibble with columns `terms`
+#' (the selectors or variables selected) and `value` (the means) is returned.
 #'
 #' @examples
 #' slack_df <- data_frame(x = 0:100)
@@ -190,6 +188,10 @@ bake.check_range <- function(object, new_data, ...) {
   col_names <- names(object$lower)
   check_new_data(col_names, object, new_data)
 
+  if (nrow(new_data) == 0) {
+    return(new_data)
+  }
+
   for (col_name in col_names) {
     range_check_func(
       new_data[[col_name]],
