@@ -5,26 +5,26 @@
 #'
 #' @inheritParams step_spline_b
 #' @param degree The degree of C-spline defined to be the degree of the
-#'  associated M-spline instead of actual polynomial degree. For example,
-#'  C-spline basis of degree 2 is defined as the scaled double integral of
-#'  associated M-spline basis of degree 2.
-#' @param options A list of options for [splines2::cSpline()]
-#'  which should not include `x`, `df`, `degree`, or `intercept`.
+#'   associated M-spline instead of actual polynomial degree. For example,
+#'   C-spline basis of degree 2 is defined as the scaled double integral of
+#'   associated M-spline basis of degree 2.
+#' @param options A list of options for [splines2::cSpline()] which should not
+#'   include `x`, `df`, `degree`, or `intercept`.
 #' @return An object with classes `"step_spline_convex"` and `"step"`.
 #' @export
 #' @details
 #'
 #' Spline transformations take a numeric column and create multiple features
 #' that, when used in a model, can estimate nonlinear trends between the column
-#' and some outcome. The degrees of freedom determines how many new features
-#' are added to the data.
+#' and some outcome. The degrees of freedom determines how many new features are
+#' added to the data.
 #'
 #' These particular spline functions have forms that are guaranteed to be
 #' convex.
 #'
-#' If the spline expansion fails for a selected column, the step will
-#' remove that column's results (but will retain the original data). Use the
-#' `tidy()` method to determine which columns were used.
+#' If the spline expansion fails for a selected column, the step will remove
+#' that column's results (but will retain the original data). Use the `tidy()`
+#' method to determine which columns were used.
 #'
 #' # Tidying
 #'
@@ -139,6 +139,9 @@ prep.step_spline_convex <- function(x, training, info = NULL, ...) {
   check_type(training[, col_names], types = c("double", "integer"))
   check_bool(x$complete_set, arg = "complete_set")
   check_number_whole(x$degree, arg = "degree", min = 0)
+  check_options(x$options, exclude = c("x", "df", "degree", "intercept"))
+
+  check_zv(training[, col_names])
 
   res <- list()
 
