@@ -510,3 +510,19 @@ test_that("bad args", {
     error = TRUE
   )
 })
+
+test_that("0 and 1 rows data work in bake method", {
+  data <- color_examples
+  rec <- recipe(~., data) %>%
+    step_dummy_extract(colors, pattern = "(?<=')[^',]+(?=')") %>%
+    prep()
+
+  expect_identical(
+    nrow(bake(rec, slice(data, 1))),
+    1L
+  )
+  expect_identical(
+    nrow(bake(rec, slice(data, 0))),
+    0L
+  )
+})
