@@ -108,6 +108,17 @@ test_that("rethrows error correctly from implementation", {
   )
 })
 
+test_that("check_options() is used", {
+  skip_if_not_installed("kernlab")
+
+  expect_snapshot(
+    error = TRUE,
+    recipe(~mpg, data = mtcars) %>%
+      step_kpca(mpg, options = TRUE) %>%
+      prep()
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -229,3 +240,21 @@ test_that("bad args", {
     error = TRUE
   )
 })
+
+test_that("0 and 1 rows data work in bake method", {
+  skip_if_not_installed("kernlab")
+
+  data <- mtcars
+  rec <- recipe(~., data) %>%
+    step_kpca(all_numeric_predictors()) %>%
+    prep()
+
+  expect_identical(
+    nrow(bake(rec, slice(data, 1))),
+    1L
+  )
+  expect_identical(
+    nrow(bake(rec, slice(data, 0))),
+    0L
+  )
+})
