@@ -138,3 +138,21 @@ test_that("printing", {
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
+
+test_that("0 and 1 rows data work in bake method", {
+  data <- mtcars
+  rec <- recipe(~., data) %>%
+    step_shuffle(all_predictors()) %>%
+    prep()
+
+  suppressWarnings(
+    expect_identical(
+      nrow(bake(rec, slice(data, 1))),
+      1L
+    )
+  )
+  expect_identical(
+    nrow(bake(rec, slice(data, 0))),
+    0L
+  )
+})
